// src/frame-app/use-resolve-context.ts
import { useCallback, useEffect, useRef, useState } from "react";
function useResolveContext({
  context
}) {
  const abortControllerRef = useRef(null);
  const [state, setState] = useState(() => {
    if (typeof context !== "function") {
      return {
        status: "success",
        context
      };
    }
    return {
      status: "pending"
    };
  });
  const resolveContext = useCallback((resolve) => {
    abortControllerRef.current?.abort();
    const abortController = new AbortController();
    abortControllerRef.current = abortController;
    Promise.resolve().then(async () => {
      setState({
        status: "pending"
      });
      const resolvedContext = await resolve({
        signal: abortController.signal
      });
      if (abortController.signal.aborted) {
        return;
      }
      setState({
        status: "success",
        context: resolvedContext
      });
    }).catch((e) => {
      if (abortController.signal.aborted) {
        return;
      }
      setState({
        status: "error",
        error: e instanceof Error ? e : new Error(String(e))
      });
    });
    return () => {
      abortController.abort(
        "Aborted because the component has been unmounted/remounted"
      );
    };
  }, []);
  useEffect(() => {
    if (typeof context !== "function") {
      setState((prevState) => {
        if (prevState.status === "success" && prevState.context !== context) {
          return {
            status: "success",
            context
          };
        }
        return prevState;
      });
    } else {
      return resolveContext(context);
    }
  }, [context, resolveContext]);
  return state;
}

export {
  useResolveContext
};
